@@ -1,12 +1,3 @@
-'''
-.. autofunction:: execute_from_config
-
-
-.. autoclass:: App
-   :members:
-   :member-order: bysource
-
-'''
 import sys
 import os
 import logging
@@ -16,12 +7,13 @@ from collections import OrderedDict
 from importlib import import_module
 
 import pulsar
-from pulsar import ImproperlyConfigured
-from pulsar.utils.httpurl import urljoin, remove_double_slash
+from pulsar import HttpException, ImproperlyConfigured
+from pulsar.utils.httpurl import remove_double_slash
 from pulsar.apps.wsgi import (WsgiHandler, HtmlDocument, test_wsgi_environ,
                               LazyWsgi)
 from pulsar.utils.pep import itervalues
 from pulsar.utils.log import lazyproperty
+from pulsar.utils.importer import module_attribute
 
 from .commands import ConsoleParser, CommandError
 from .extension import Extension, Parameter, EventHandler
@@ -45,7 +37,7 @@ ALL_EVENTS = ('on_config',  # Config ready.
 
 
 def execute_from_config(config_file, argv=None, **params):
-    '''Create and run an :class:`App` from a ``config_file``.
+    '''Create and run an :class:`.Application` from a ``config_file``.
 
     This is the function to use when creating the script which runs your
     web applications::
@@ -121,14 +113,19 @@ class App(LazyWsgi):
 
 
 class Application(ConsoleParser, Extension):
-    '''A lux :class:`App` is the WSGI callable for serving lux applications.
+    '''The :class:`.Application` is the WSGI callable for serving
+    lux applications.
 
     It is a specialised :class:`~.Extension` which collects
     all extensions of your application and setup the wsgi middleware used by
     the web server.
     An :class:`App` is not usually initialised directly, the higher level
-    :func:`execute_from_config` is used instead.
+    :func:`.execute_from_config` is used instead.
 
+    .. attribute:: config
+
+        The configuration dictionary containing all patameters specified in
+        the :attr:`config_module`.
 
     .. attribute:: debug
 
@@ -136,6 +133,13 @@ class Application(ConsoleParser, Extension):
 
             python myappscript.py serve --debug
 
+    .. attribute:: handler
+
+        The :class:`~pulsar.apps.wsgi.handlers.WsgiHandler` for this
+        application. It is created the first time the callable
+        method of this :class:`.Application` is accessed by the WSGI
+        server.
+
     .. attribute:: auth_backend
 
         Used by the sessions extension
@@ -213,7 +217,9 @@ class Application(ConsoleParser, Extension):
                    'supporting the cache protocol')),
         Parameter('DEFAULT_FROM_EMAIL', '',
                   'Default email address to send email from'),
-        Parameter('LOCALE', 'en_GB', 'Default locale')
+        Parameter('LOCALE', 'en_GB', 'Default locale'),
+        Parameter('EMAIL_BACKEND', 'lux.core.mail.EmailBackend',
+                  'Default locale')
         ]
 
     def __init__(self, callable):
@@ -244,7 +250,7 @@ class Application(ConsoleParser, Extension):
         '''Ordered dictionary of :class:`.Extension` available.
 
         The order is the same as in the
-        :ref:`EXTENSIONS config <configuration>` parameter.
+        :setting:`EXTENSIONS` config parameter.
         '''
         return self.config['EXTENSION_HANDLERS']
 
@@ -255,15 +261,13 @@ class Application(ConsoleParser, Extension):
 
     def wsgi_request(self, environ=None, loop=None, path=None,
                      app_handler=None, urlargs=None, **kw):
-        '''Create a :class:`WsgiRequest` from a wsgi ``environ`` and set the
+        '''Create a :class:`.WsgiRequest` from a wsgi ``environ`` and set the
         ``app`` attribute in the cache.
         Additional keyed-valued parameters can be inserted.
         '''
         if not environ:
             # No WSGI environment, build a test one
-            environ = test_wsgi_environ(path=path, loop=loop)
-        if kw:
-            environ.update(kw)
+            environ = test_wsgi_environ(path=path, loop=loop, **kw)
         request = wsgi_request(environ, app_handler=app_handler,
                                urlargs=urlargs)
         environ['error.handler'] = self.config['ERROR_HANDLER']
@@ -282,22 +286,22 @@ class Application(ConsoleParser, Extension):
         Usually there is no need to call directly this method.
         Instead one can use the :attr:`.WsgiRequest.html_document`.
         '''
-        handler = request.app_handler
-        title = None
-        if handler:
-            title = handler.parameters.get('title')
         cfg = self.config
         site_url = cfg['SITE_URL']
         media_path = cfg['MEDIA_URL']
         if site_url:
             media_path = site_url + media_path
-        doc = HtmlDocument(title=title or cfg['HTML_TITLE'],
+        doc = HtmlDocument(title=cfg['HTML_TITLE'],
                            media_path=media_path,
                            minified=cfg['MINIFIED_MEDIA'],
                            data_debug=self.debug,
                            charset=cfg['ENCODING'],
                            asset_protocol=cfg['ASSET_PROTOCOL'])
         doc.meta = HeadMeta(doc.head)
+        doc.jscontext = {'dateFormat': cfg['DATE_FORMAT'],
+                         'datetimeFormat': cfg['DATETIME_FORMAT'],
+                         'media': cfg['MEDIA_URL'],
+                         'brand': cfg['APP_NAME']}
         # Locale
         lang = cfg['LOCALE'][:2]
         doc.attr('lang', lang)
@@ -310,7 +314,8 @@ class Application(ConsoleParser, Extension):
         if required:
             head.scripts.append(cfg['REQUIREJS_CONFIG'])
             head.scripts.append(cfg['REQUIREJS_URL'])
-            head.scripts.require.extend(required)
+            head.scripts.require.extend((media_path+r[1:] if r.startswith('.')
+                                         else r for r in required))
         #
         for entry in cfg['HTML_META'] or ():
             head.add_meta(**entry)
@@ -348,6 +353,13 @@ class Application(ConsoleParser, Extension):
                 pass    # No management module
         return cmnds
 
+    @lazyproperty
+    def email_backend(self):
+        '''Email backend for this application
+        '''
+        dotted_path = self.config['EMAIL_BACKEND']
+        return module_attribute(dotted_path)(self)
+
     def get_command(self, name, stdout=None, stderr=None):
         '''Construct and return a :class:`.Command` for this application
         '''
@@ -419,6 +431,8 @@ class Application(ConsoleParser, Extension):
             for handler in handlers:
                 try:
                     handler(self, *args)
+                except HttpException:
+                    raise
                 except Exception:
                     self.logger.critical(
                         'Unhandled exception while firing event %s', handler,
@@ -450,6 +464,7 @@ class Application(ConsoleParser, Extension):
     def format_datetime(self, dte):
         return dte.strftime(self.config['DATETIME_FORMAT'])
 
+    # Template redering
     def template_full_path(self, name):
         '''Return the template full path or None.
 
@@ -460,9 +475,17 @@ class Application(ConsoleParser, Extension):
             filename = os.path.join(ext.meta.path, 'templates', name)
             if os.path.exists(filename):
                 return filename
+        self.logger.error('Template %s not found' % name)
 
     def template(self, name):
-        '''Load a template from the file system
+        '''Load a template from the file system.
+
+        The template is must be located in a ``templates`` directory
+        of at least one of the extensions included in the :setting:EXTENSIONS`
+        list. The location of the template file is obtained via
+        the :meth:`template_full_path` method.
+
+        If the file is not found an empty string is returned.
         '''
         filename = self.template_full_path(name)
         if filename:
@@ -470,25 +493,28 @@ class Application(ConsoleParser, Extension):
                 return file.read()
         return ''
 
-    def context(self, request, context=None, js=None):
-        '''Load the ``context`` dictionary for this ``request``
+    def context(self, request, context=None):
+        '''Load the ``context`` dictionary for a ``request``.
+
+        This function is called every time a template is rendered via the
+        :meth:`render_template` method is used and a the wsgi ``request``
+        is passed as key-valued parameter.
+
+        The initial ``context`` is updated with contribution from
+        all :setting:`EXTENSIONS` which expose the ``context`` method.
         '''
         context = context if context is not None else {}
-        if js:
-            method = 'jscontext'
-            cfg = self.config
-            context.update({'dateFormat': cfg['DATE_FORMAT'],
-                            'datetimeFormat': cfg['DATETIME_FORMAT']})
-        else:
-            method = 'context'
         for ext in self.extensions.values():
-            if hasattr(ext, method):
-                context = getattr(ext, method)(request, context) or context
+            if hasattr(ext, 'context'):
+                context = ext.context(request, context) or context
         return context
 
-    def render_template(self, template_name, context=None, engine=None):
-        '''Render a template'''
-        template = self.template(template_name)
+    def render_template(self, name, context=None, request=None, engine=None):
+        '''Render a template file ``name`` with ``context``
+        '''
+        if request:
+            context = self.context(request, context)
+        template = self.template(name)
         rnd = self.template_engine(engine)
         return rnd(template, context)
 
@@ -507,16 +533,18 @@ class Application(ConsoleParser, Extension):
         if 'text/html' in request.content_types:
             request.response.content_type = 'text/html'
             doc = request.html_document
+            if jscontext:
+                doc.jscontext.update(jscontext)
             head = doc.head
             if title:
                 head.title = title % head.title
             if status_code:
                 request.response.status_code = status_code
             context = self.context(request, context)
-            jscontext = self.context(request, jscontext, 'js')
-            if jscontext:
-                jscontext = json.dumps(jscontext)
-                doc.head.embedded_js.append('var luxContext = %s;' % jscontext)
+            if doc.jscontext:
+                jscontext = json.dumps(doc.jscontext)
+                doc.head.embedded_js.insert(
+                    0, 'var lux = {context: %s};\n' % jscontext)
             body = self.render_template(template_name, context)
             doc.body.append(body)
             return doc.http_response(request)
@@ -531,6 +559,16 @@ class Application(ConsoleParser, Extension):
         else:
             return path
 
+    def media_url(self, path=None):
+        '''Build the media url from an optional ``path``
+        '''
+        base = self.config['SITE_URL'] + self.config['MEDIA_URL']
+        path = path or '/'
+        if base:
+            return '%s%s' % (base, path) if path else base
+        else:
+            return path or '/'
+
     # INTERNALS
     def _build_config(self, file):
         # Check if an extension module is available
@@ -542,8 +580,8 @@ class Application(ConsoleParser, Extension):
                 self.meta.version = extension.meta.version
             if not self.meta.has_module:
                 raise RuntimeError('Invalid project setup. The Application '
-                                   'config module must be within a valid python '
-                                   'module.')
+                                   'config module must be within a valid '
+                                   'python module.')
         params = self.callable._params
         parser = self.get_parser(with_commands=False, add_help=False)
         opts, _ = parser.parse_known_args(self.meta.argv)
@@ -598,7 +636,6 @@ class Application(ConsoleParser, Extension):
 
 
 def add_app(apps, name, pos=None):
-    '''Insert a name to the list'''
     try:
         apps.remove(name)
     except ValueError:
