@@ -1,50 +1,3 @@
-'''
-Symbolic
-~~~~~~~~~~~~~~~~~~~~
-.. autoclass:: Symbolic
-   :members:
-   :member-order: bysource
-
-Variable
-~~~~~~~~~~~~~~~~~~~~
-.. autoclass:: Variable
-   :members:
-   :member-order: bysource
-
-Symbol
-~~~~~~~~~~~~~~
-.. autoclass:: Symbol
-   :members:
-   :member-order: bysource
-
-Lazy
-~~~~~~~~~~~~~~
-.. autoclass:: Lazy
-   :members:
-   :member-order: bysource
-
-Variables
-~~~~~~~~~~~~~~
-.. autoclass:: Variables
-   :members:
-   :member-order: bysource
-
-Spacing
-~~~~~~~~~~~~~
-.. autoclass:: Spacing
-   :members:
-   :member-order: bysource
-
-.. autofunction:: spacing
-
-Mixin
-~~~~~~~~~~~~~
-
-.. autoclass:: Mixin
-   :members:
-   :member-order: bysource
-
-'''
 import os
 import json
 import time
@@ -93,11 +46,13 @@ def alltags(tags):
                 yield ' %s' % tag
 
 
-def as_value(v):
-    if hasattr(v, 'value'):
-        return v.value()
+def as_value(value):
+    '''Internal function used to convert any ``value`` into a suitable
+    string to include into the css rules.'''
+    if hasattr(value, 'value'):
+        return value.value()
     else:
-        return v
+        return value
 
 
 def as_params(value, default_name=None):
@@ -384,7 +339,7 @@ class Spacing(Unit):
 
 
 ############################################################################
-##    factory functions
+#    factory functions
 px = lambda v: size(v, unit='px')
 pc = lambda v: size(v, unit='%')
 em = lambda v: size(v, unit='em')
@@ -462,7 +417,7 @@ class Mixin(CssBase):
             parent.add_child(self)
 
 
-################################################# Media
+# ################################################ Media
 class Media(Mixin):
     '''Add @media queries to css.'''
     def __init__(self, type, query):
@@ -760,12 +715,13 @@ class Css(CssBase):
         body = root.render()
         created = datetime.fromtimestamp(int(start))
         nice_dt = round(time.time() - start, 2)
-        intro = '''\
+        intro = '''@charset "UTF-8";
 /*
 ------------------------------------------------------------------
-------------------------------------------------------------------
-Created by lux {0} in {1} seconds.
-------------------------------------------------------------------
+Created by lux in {1} seconds
+Date: {0}
+
+http://quantmind.github.io/lux/
 ------------------------------------------------------------------ */
 
 '''.format(created.isoformat(' '), nice_dt)
@@ -788,7 +744,7 @@ Created by lux {0} in {1} seconds.
                         app.write('Imported style from "%s".' % extension)
                 except ImportError as e:
                     app.write_err('Cannot import style %s: "%s".' %
-                                   (extension, e))
+                                  (extension, e))
         if dump_variables:
             data = root.variables.tojson()
             return json.dumps(data, indent=4)
