@@ -1,64 +1,13 @@
-'''
-Bcd
-~~~~~
-.. autoclass:: Bcd
-
-Border
-~~~~~~~~~
-.. autoclass:: Border
-
-BoxSizing
-~~~~~~~~~~~~~~~
-.. autoclass:: BoxSizing
-
-Clearfix
-~~~~~~~~~
-.. autoclass:: Clearfix
-
-Clickable
-~~~~~~~~~~~~
-.. autoclass:: Clickable
-
-CssInclude
-~~~~~~~~~~~~~
-.. autoclass:: CssInclude
-
-Fontface
-~~~~~~~~~~~~~~
-.. autoclass:: Fontface
-
-Gradient
-~~~~~~~~~~~~~~~
-.. autoclass:: Gradient
-
-
-Opacity
-~~~~~~~~~
-.. autoclass:: Opacity
-
-Radius
-~~~~~~~~~
-.. autoclass:: Radius
-
-Shadow
-~~~~~~~~
-.. autoclass:: Shadow
-
-Stack
-~~~~~~~
-.. autoclass:: Stack
-
-Transition
-~~~~~~~~~~~~~~~~~
-.. autoclass:: Transition
-'''
 import os
 
 from .base import *
 from .colorvar import *
+from .. import CssLibraries
 
-__all__ = ['Opacity',
+__all__ = ['Animation',
+           'Opacity',
            'Clearfix',
+           'CenterBlock',
            'InlineBlock',
            'Textoverflow',
            'clear_anchor',
@@ -75,8 +24,8 @@ __all__ = ['Opacity',
            'Bcd',
            'bcd',
            'Clickable',
+           'Transform',
            'Transition',
-           'horizontal_navigation',
            # generators
            'CssInclude',
            'Image',
@@ -84,17 +33,70 @@ __all__ = ['Opacity',
            'FontSmoothing',
            'Stack']
 
+
 ############################################################################
-##    BATTERY INCLUDED MIXINS
+#    BATTERY INCLUDED MIXINS
 ############################################################################
 
 
-################################################# OPACITY
+# ################################################ ANIMATION
+class Animation(Mixin):
+    '''Bind the animation to a selector (element) by specifying at least
+    these two properties:
+
+    .. attribute:: name
+
+        the name of the animation
+
+    .. attribute:: duration
+
+        the duration of the animation
+
+
+    **Usage**::
+
+        css('.myelement',
+            Animation('fade', '1s'))
+    '''
+    def __init__(self, name=None, duration=None, function=None,
+                 fill_mode=None):
+        self.name = name
+        self.duration = duration
+        self.function = function
+        self.fill_mode = fill_mode
+
+    def __call__(self, elem):
+        name = as_value(self.name)
+        duration = as_value(self.duration)
+        function = as_value(self.function)
+        fill_mode = as_value(self.fill_mode)
+        if name:
+            elem['-webkit-animation-name'] = name
+            elem['   -moz-animation-name'] = name
+        if duration:
+            elem['-webkit-animation-duration'] = duration
+            elem['   -moz-animation-duration'] = duration
+        if function:
+            elem['-webkit-animation-timing-function'] = function
+            elem['   -moz-animation-timing-function'] = function
+        if fill_mode:
+            elem['-webkit-animation-fill-mode'] = fill_mode
+            elem['        animation-fill-mode'] = fill_mode
+
+
+# ################################################ OPACITY
 class Opacity(Mixin):
     '''Add opacity to an element.
 
-param o: a number between 0 and 1.
-'''
+    .. attribute:: o
+
+        a number between 0 and 1
+
+    **Usage**::
+
+        css('.myelem',
+            Opacity(0.6))
+    '''
     def __init__(self, o):
         self.o = o
 
@@ -106,7 +108,7 @@ param o: a number between 0 and 1.
         elem['filter'] = 'alpha(opacity=%s)' % (100*value)
 
 
-################################################# CLEARFIX
+# ################################################ CLEARFIX
 class Clearfix(Mixin):
     '''A ``clearfix`` is a way for an element to automatically clear after
 itself, so that you don't need to add additional markup.
@@ -119,7 +121,7 @@ stacked horizontally.'''
         elem.css(':after', clear='both')
 
 
-################################################# InlineBlock
+# ################################################ InlineBlock
 class InlineBlock(Mixin):
     '''Cross browser inline block form
 
@@ -131,7 +133,16 @@ http://foohack.com/2007/11/cross-browser-support-for-inline-block-styling/'''
         elem['*display'] = 'inline'
 
 
-################################################# TEXT OVERFLOW
+# ################################################ CenterBlock
+class CenterBlock(Mixin):
+    '''Center block a-la bootstrap'''
+    def __call__(self, elem):
+        elem['display'] = 'block'
+        elem['margin-left'] = 'auto'
+        elem['margin-right'] = 'auto'
+
+
+# ################################################ TEXT OVERFLOW
 class Textoverflow(Mixin):
 
     def __call__(self, elem):
@@ -150,7 +161,7 @@ class clear_anchor(Mixin):
                  cursor='inherit')
 
 
-################################################# FIXTOP
+# ################################################ FIXTOP
 class fixtop(Mixin):
     '''Fix an element at the top of the page.'''
     def __init__(self, zindex=2000):
@@ -173,7 +184,7 @@ class unfixtop(Mixin):
         elem['z_index'] = 'auto'
 
 
-################################################# CSS BORDER
+# ################################################ CSS BORDER
 class Border(Mixin):
     '''A :class:`Mixin` for adding border to a css element.
 
@@ -222,40 +233,40 @@ class Border(Mixin):
         return ' '.join(bits)
 
 
-################################################# CSS3 BOX SHADOW
+# ################################################ CSS3 BOX SHADOW
 class Shadow(Mixin):
     '''The box-shadow css3 property attaches one or more drop-shadows to the
-box. The property is a comma-separated list of shadows, each specified by
-2-4 length values, an optional color, and an optional inset keyword.
-Omitted lengths are 0::
+    box. The property is a comma-separated list of shadows, each specified by
+    2-4 length values, an optional color, and an optional inset keyword.
+    Omitted lengths are 0::
 
-    Shadow(hshadow, vshadow, blur, spread, color, inset)
+        Shadow(hshadow, vshadow, blur, spread, color, inset)
 
-.. attribute:: hshadow
+    .. attribute:: hshadow
 
-    The position of the horizontal shadow. Negative values are allowed.
+        The position of the horizontal shadow. Negative values are allowed.
 
-.. attribute:: vshadow
+    .. attribute:: vshadow
 
-    The position of the vertical shadow. Negative values are allowed.
+        The position of the vertical shadow. Negative values are allowed.
 
-.. attribute:: blur
+    .. attribute:: blur
 
-    Optional blur distance.
+        Optional blur distance.
 
-.. attribute:: spread
+    .. attribute:: spread
 
-    The size of shadow.
+        The size of shadow.
 
-.. attribute:: color
+    .. attribute:: color
 
-    Optional color of the shadow.
+        Optional color of the shadow.
 
-.. attribute:: inset
+    .. attribute:: inset
 
-    Optional boolean to changes the shadow from an outer shadow (outset)
-    to an inner shadow.
-'''
+        Optional boolean to changes the shadow from an outer shadow (outset)
+        to an inner shadow.
+    '''
     def __init__(self, hshadow=None, vshadow=None, blur=None, spread=None,
                  color=None, inset=None):
         self.hshadow = hshadow
@@ -289,7 +300,7 @@ Omitted lengths are 0::
             elem['        box-shadow'] = shadow
 
 
-################################################# CSS3 BOX SIZING
+# ################################################ CSS3 BOX SIZING
 class BoxSizing(Mixin):
     '''The box-sizing CSS3 property.
 
@@ -322,12 +333,12 @@ The only parameter is ``value`` which can be one of:
             elem['        box-sizing'] = value
 
 
-################################################# CSS3 RADIUS
+# ################################################ CSS3 RADIUS
 class Radius(Mixin):
     '''css3 border radius. The optional location parameter specifies the
-location where to apply the radius. For example, 'top', 'bottom', 'left',
-'right', 'top-left', 'top-right' and so on.
-'''
+    location where to apply the radius. For example, 'top', 'bottom', 'left',
+    'right', 'top-left', 'top-right' and so on.
+    '''
     def __init__(self, radius, location=None):
         if isinstance(radius, Radius):
             radius = radius.radius
@@ -357,30 +368,39 @@ location where to apply the radius. For example, 'top', 'bottom', 'left',
                 elem['        border%s-radius' % l] = r
 
 
-################################################# CSS3 BACKGROUNd
+# ################################################ CSS3 BACKGROUNd
 class Background(Mixin):
-
-    def __init__(self, url=None, size=None, repeat=None, position=None):
+    '''Set the background property of an element
+    '''
+    def __init__(self, url=None, size=None, repeat=None, position=None,
+                 attachment=None):
         self.url = url
         self.size = size
         self.repeat = repeat
         self.position = position
+        self.attachment = attachment
 
     def __call__(self, elem):
+        size = as_value(self.size)
+        repeat = as_value(self.repeat)
+        position = as_value(self.position)
+        attachment = as_value(self.attachment)
         if self.url:
             elem['background-image'] = "url(%s)" % self.url
-        if self.size:
-            elem['-webkit-background-size'] = self.size
-            elem['   -moz-background-size'] = self.size
-            elem['     -o-background-size'] = self.size
-            elem['        background-size'] = self.size
-        if self.repeat:
-            elem['background-repeat'] = self.repeat
-        if self.position:
-            elem['background-position'] = self.position
+        if size:
+            elem['-webkit-background-size'] = size
+            elem['   -moz-background-size'] = size
+            elem['     -o-background-size'] = size
+            elem['        background-size'] = size
+        if repeat:
+            elem['background-repeat'] = repeat
+        if position:
+            elem['background-position'] = position
+        if attachment:
+            elem['background-attachment'] = attachment
 
 
-################################################# CSS3 GRADIENT
+# ################################################ CSS3 GRADIENT
 class Gradient(Mixin):
     '''css3 gradient. Don't initialise directly, use :func:`gradient`
 instead.
@@ -468,7 +488,7 @@ instead.
                           "GradientType={2})".format(s, e, t))
         #
         # Reset filters for IE
-        #elem['filter'] = ('progid:DXImageTransform.Microsoft.gradient'
+        # elem['filter'] = ('progid:DXImageTransform.Microsoft.gradient'
         #                  '(enabled = false)')
 
     def hgradient(self, elem, d, s, e):
@@ -485,7 +505,7 @@ def gradient(*args):
         return Gradient(*args)
 
 
-################################################# PLACEHOLDER
+# ################################################ PLACEHOLDER
 class Placeholder(Mixin):
 
     def __init__(self, color):
@@ -499,7 +519,7 @@ class Placeholder(Mixin):
              color=self.color)
 
 
-################################################# BCD - BACKGROUND-COLOR-DECO
+# ################################################ BCD - BACKGROUND-COLOR-DECO
 class Bcd(Mixin):
     '''Background-color-decorator :class:`Mixin`.
 
@@ -540,7 +560,7 @@ def bcd(params):
         return Bcd(**as_params(params))
 
 
-################################################# CLICKABLE
+# ################################################ CLICKABLE
 class Clickable(Mixin):
     '''Defines the default, hover and active state.'''
     def __init__(self, default=None, hover=None, active=None, cursor='pointer',
@@ -561,7 +581,78 @@ class Clickable(Mixin):
             elem.css(':active,.%s' % classes.active, self.active)
 
 
-################################################# TRANSITION
+# ################################################ TRANSLATE
+class Transform(Mixin):
+    '''Defines a 2D transform.
+
+    A transform is controlled via the following parameters:
+
+    .. attribute:: x
+
+        Movement along the X-axis
+
+    .. attribute:: y
+
+        Movement along the Y-axis
+
+    .. attribute:: scale
+
+        Increases or decreases the size
+
+    .. attribute:: scalex
+
+        Increases or decreases the size in the X-axis (not used if
+        :attr:`scale` is defined)
+
+    .. attribute:: scaley
+
+        Increases or decreases the size in the Y-axis (not used if
+        :attr:`scale` is defined)
+
+    **Usage**::
+
+        css('.myelement',
+            Transform(x=pc(100)))
+
+        css('.myelement',
+            Transform(x=pc(100), scale=1.1))
+    '''
+    def __init__(self, x=None, y=None, scale=None, scalex=None, scaley=None):
+        self.x = x
+        self.y = y
+        self.scale = scale
+        self.scalex = scalex
+        self.scaley = scaley
+
+    def __call__(self, elem):
+        x = as_value(self.x)
+        y = as_value(self.y)
+        if x is not None or y is not None:
+            if y is None:
+                translate = 'translateX(%s)' % x
+            elif x is None:
+                translate = 'translateY(%s)' % y
+            else:
+                translate = 'translate(%s,%s)' % (x, y)
+            self._add(elem, translate)
+        scale = as_value(self.scale)
+        scalex = as_value(self.scalex)
+        scaley = as_value(self.scaley)
+        if scale is not None:
+            self._add(elem, 'scale(%s)' % scale)
+        else:
+            if scalex is not None:
+                self._add(elem, 'scaleX(%s)' % scalex)
+            if scaley is not None:
+                self._add(elem, 'scaleY(%s)' % scaley)
+
+    def _add(self, elem, value):
+        elem['-webkit-transform'] = value
+        elem['    -ms-transform'] = value
+        elem['        transform'] = value
+
+
+# ################################################ TRANSITION
 class Transition(Mixin):
     '''Define a CSS3 transition.
 
@@ -630,147 +721,7 @@ class Transition(Mixin):
         elem['        transition'] = transition
 
 
-################################################# HORIZONTAL NAVIGATION
-class horizontal_navigation(Clickable):
-    '''Horizontal navigation with ul and li tags.
-
-:parameter padding: the padding for the navigation anchors.'''
-    def __init__(self,
-                 float='left',
-                 margin=0,
-                 height=None,
-                 padding=None,
-                 secondary_default=None,
-                 secondary_hover=None,
-                 secondary_active=None,
-                 secondary_padding=None,
-                 secondary_width=None,
-                 radius=None,
-                 box_shadow=None,
-                 display_all=False,
-                 z_index=None,
-                 **kwargs):
-        super(horizontal_navigation, self).__init__(**kwargs)
-        if float not in ('left', 'right'):
-            float = 'left'
-        self.float = float
-        self.margin = margin
-        self.height = height
-        self.secondary_default = secondary_default
-        self.secondary_hover = secondary_hover
-        self.secondary_active = secondary_active
-        self.secondary_width = secondary_width or px(120)
-        self.radius = Radius(radius)
-        self.box_shadow = Shadow(box_shadow)
-        self.display_all = display_all
-        # padding
-        self.padding = padding or secondary_padding
-        self.secondary_padding = secondary_padding or px(0)
-        # Z index for subnavigations
-        self.z_index = z_index or 1000
-
-    def list(self, tag, parent, default, hover, active):
-        return css(tag,
-                   default.background,
-                   css('> a',
-                       bcd(background='transparent',
-                           color=default.color,
-                           text_decoration=default.text_decoration,
-                           text_shadow=default.text_shadow)),
-                   css(':hover',
-                       hover.background,
-                       css('> a',
-                           bcd(color=hover.color,
-                               text_decoration=hover.text_decoration,
-                               text_shadow=hover.text_shadow)),
-                       css('> ul', display='block')),
-                   css(':active, .%s' % classes.state_active,
-                       active.background,
-                       css('> a',
-                           bcd(color=active.color,
-                               text_decoration=active.text_decoration,
-                               text_shadow=active.text_shadow))),
-                   cursor='pointer',
-                   parent=parent)
-
-    def __call__(self, elem):
-        elem['display'] = 'block'
-        elem['float'] = self.float
-        elem['position'] = 'relative'
-        elem['padding'] = 0
-        if self.margin:
-            if self.float == 'left':
-                elem['margin'] = spacing(0, self.margin, 0, 0)
-            else:
-                elem['margin'] = spacing(0, 0, 0, self.margin)
-        self.box_shadow(elem)
-        padding = (spacing(self.padding) if self.padding else
-                   spacing(px(10), px(10)))
-        #
-        default = self.default or bcd()
-        hover = self.hover or bcd()
-        active = self.active or bcd()
-        # li elements in the main navigation ( > li)
-        li = self.list('> li', elem, default, hover, active)
-        li['display'] = 'block'
-        li['float'] = 'left'
-
-        if self.height:
-            line_height = self.height - padding.top - padding.bottom
-            if line_height.value <= 0:
-                raise ValueError('Nav has height to low compared to paddings')
-        else:
-            line_height = None
-
-        # subnavigations
-        default = self.secondary_default or default
-        hover = self.secondary_hover or hover
-        active = self.secondary_active or active
-        ul = css('ul',
-                 self.radius,
-                 gradient(default.background, 100),
-                 parent=elem,
-                 cursor='default',
-                 position='absolute',
-                 margin=0,
-                 padding=self.secondary_padding,
-                 top=self.height,
-                 width=self.secondary_width,
-                 list_style='none',
-                 list_style_image='none',
-                 z_index=self.z_index)
-        if not self.display_all:
-            ul['display'] = 'none'
-        # The sub lists li
-        li = self.list('li', ul, default, hover, active)
-        li['padding'] = 0
-        li['margin'] = 0
-        li['position'] = 'relative'
-        li['border'] = 'none'
-        li['width'] = 'auto'
-        # the sub sub lists
-        ulul = css('ul',
-                   gradient(default.background, 100),
-                   parent=li,
-                   top=0,
-                   position='absolute')
-        if self.float == 'right':
-            ul['right'] = 0
-            ulul['left'] = 'auto'
-            ulul['right'] = self.secondary_width
-        else:
-            ulul['left'] = self.secondary_width
-            ulul['right'] = 'auto'
-        # The anchor
-        css('a',
-            parent=elem,
-            display='inline-block',
-            float='none',
-            line_height=line_height,
-            padding=self.padding)
-
-
-################################################# INCLUDE CSS
+# ################################################ INCLUDE CSS
 class CssInclude(Mixin):
     '''Include one or more css resources. The correct use of this
     :class:`.Mixin` is within the ``body`` tag only::
@@ -801,6 +752,12 @@ class CssInclude(Mixin):
 
     def __call__(self, elem):
         path = self.path
+        if path in CssLibraries:
+            path = CssLibraries[path]
+            if not path.endswith('.css'):
+                path = '%s.css' % path
+            if path.startswith('//'):
+                path = 'http:%s' % path
         if not path.startswith('http'):
             if os.path.isfile(path):
                 with open(path, 'r') as f:
@@ -816,6 +773,8 @@ class CssInclude(Mixin):
         root = elem.root
         if self.location:
             stream = '\n'.join(self.correct(root, stream))
+        if stream.startswith('@charset'):
+            stream = ';'.join(stream.split(';')[1:])
         return stream
 
     def correct(self, root, stream):
@@ -878,7 +837,7 @@ class Image(Mixin):
             elem['background-position'] = self.position
 
 
-################################################# FONT-FACE
+# ################################################ FONT-FACE
 class Fontface(Mixin):
 
     def __init__(self, base, svg=None):
@@ -905,7 +864,7 @@ class FontSmoothing(Mixin):
         elem['-webkit-font-smoothing'] = 'antialiased'
 
 
-################################################# Stack
+# ################################################ Stack
 class Stack(Mixin):
     '''Stack :class:`Stackable` mixins.'''
     def __init__(self, *mixins):
