@@ -32,21 +32,28 @@ Form
 =========================
 
 .. automodule:: lux.forms.form
+   :members:
+   :member-order: bysource
 
 Fields
 =========================
 
 .. automodule:: lux.forms.fields
+   :members:
+   :member-order: bysource
 
 Layout
 =========================
 
-.. automodule:: lux.forms.layouts
+.. automodule:: lux.forms.serialise
+   :members:
+   :member-order: bysource
 
 
 .. _django: https://www.djangoproject.com/
 '''
+from .options import *
 from .fields import *
 from .formsets import *
-from .layouts import *
 from .form import *
+from .serialise import *
