@@ -1,8 +1,3 @@
-'''
-.. autoclass:: Form
-   :members:
-   :member-order: bysource
-'''
 import json
 from collections import Mapping
 from functools import partial
@@ -17,7 +12,7 @@ from lux.utils import JSON_CONTENT_TYPES
 
 from .formsets import FormSet
 from .fields import Field, ValidationError, FormError
-from .layouts import Layout, FORMKEY
+from .serialise import Layout, FORMKEY
 
 
 __all__ = ['FormType',
@@ -44,21 +39,21 @@ def smart_redirect(request, url=None, status=None):
 
 class FieldList(list):
     '''A list of :class:`Field` and :class:`FieldList`.
- It can be used to specify fields using a declarative list in a
- :class:`Form` class.
- For example::
+     It can be used to specify fields using a declarative list in a
+     :class:`Form` class.
+     For example::
 
-     from djpcms import forms
+         from djpcms import forms
 
-     class MyForm(forms.Form):
-         some_fields = forms.FieldList(('name',forms.CharField()),
-                                       ('description',forms.CharField()))
+         class MyForm(forms.Form):
+             some_fields = forms.FieldList(('name',forms.CharField()),
+                                           ('description',forms.CharField()))
 
-.. attribute:: withprefix
+    .. attribute:: withprefix
 
-    if ``True`` the :class:`Fieldlist` attribute name in the form is
-    prefixed to the field names.
-'''
+        if ``True`` the :class:`Fieldlist` attribute name in the form is
+        prefixed to the field names.
+    '''
     def __init__(self, data=None, withprefix=True):
         self.withprefix = withprefix
         super(FieldList, self).__init__(data or ())
@@ -112,16 +107,13 @@ def get_form_meta_data(bases, attrs, with_base_fields=True):
 
 
 class FormType(type):
-    """
-    Metaclass that converts Field attributes to a dictionary called
-    'base_fields', taking into account parent class 'base_fields' as well.
-    """
+
     def __new__(cls, name, bases, attrs):
         layout = attrs.pop('layout', None)
         fields, inlines = get_form_meta_data(bases, attrs)
         attrs['base_fields'] = fields
         attrs['base_inlines'] = inlines
-        if not isinstance(layout, Layout):
+        if layout is None:
             layout = Layout()
         attrs['layout'] = layout
         return super(FormType, cls).__new__(cls, name, bases, attrs)
@@ -238,15 +230,15 @@ class Form(FormType('BaseForm', (UnicodeMixin,), {})):
     def _loop(self):
         return getattr(self.request, '_loop', None)
 
-    def is_valid(self):
+    def is_valid(self, exclude_missing=False):
         '''Asynchronous check if this :class:`Form` is valid.
 
         Includes any subforms. It returns a coroutine.'''
         if not self._check_unwind(False):
-            self._unwind()
+            self._unwind(exclude_missing)
             if not bool(self._errors):
                 for fset in self.form_sets.values():
-                    if not fset.is_valid():
+                    if not fset.is_valid(exclude_missing):
                         break
         return not bool(self._errors) if self.is_bound else False
 
@@ -350,10 +342,6 @@ instances with initial values.'''
                 fset.set_save_as_new()
         return self.save(commit=commit)
 
-    def submit(self):
-        '''Submit the form once the validation has been successful. Must
-be implemented by subclasses. By default it does nothing.'''
-
     def tojson(self):
         '''Return a json-serialisable dictionary of messages for form fields.
         The field included are the one available in the :attr:`errors` and
@@ -403,13 +391,13 @@ be implemented by subclasses. By default it does nothing.'''
                 return False
         return True
 
-    def _unwind(self):
+    def _unwind(self, exclude_missing=False):
         is_bound = self.is_bound
         if is_bound:
             self._cleaned_data = {}
             self._errors = {}
         rawdata = self.rawdata
-        self._clean_fields(rawdata)
+        self._clean_fields(rawdata, exclude_missing)
         if is_bound:
             if not self._errors:
                 # Invoke the form clean method.
@@ -421,8 +409,7 @@ be implemented by subclasses. By default it does nothing.'''
             if self._errors:
                 del self._cleaned_data
 
-    def _clean_fields(self, rawdata):
-        loop = self._loop
+    def _clean_fields(self, rawdata, exclude_missing):
         files = self._files
         self._data = data = {}
         self._fields = fields = []
@@ -433,6 +420,8 @@ be implemented by subclasses. By default it does nothing.'''
         for name, field in iteritems(self.base_fields):
             bfield = BoundField(self, field, name, self.prefix)
             key = bfield.html_name
+            if is_bound and exclude_missing and key not in rawdata:
+                continue
             fields.append(bfield)
             dfields[name] = bfield
             field_value = None
